
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.17.8',
    'branch_nick': 'patch-0-Rucio_1_17_8_preparation',
    'revision_id': '136b9a54b61a94ad421cda5d60490357d172d5cd',
    'revno': 6955
}
